@@ -57,7 +57,7 @@ List xBigSolveForc(Mat<T> Eigenvectors, const colvec Eigenvalues,
 List BigSolveForc(SEXP pEigenvectors, const arma::colvec Eigenvalues, 
                       const arma::colvec y, const double lambda) {
   
-  XPtr<BigMatrix> xpEigenvectors(pEigenvectors);
+  XPtr<SharedMemoryBigMatrix> xpEigenvectors(pEigenvectors);
   
   List out = xBigSolveForc(arma::Mat<double>((double *)xpEigenvectors->matrix(), 
                                              xpEigenvectors->nrow(), 
